Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5913)

Unified Diff: chrome/browser/policy/device_management_service.cc

Issue 6338002: net: Remove typedef net::URLRequestContext URLRequestContext; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: for real Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/device_management_service.cc
diff --git a/chrome/browser/policy/device_management_service.cc b/chrome/browser/policy/device_management_service.cc
index f069d03e22771d2a4d7fbe9e9d78c2492de12004..e29d21aa4380135b8b8e62610b91961eb6b3e516 100644
--- a/chrome/browser/policy/device_management_service.cc
+++ b/chrome/browser/policy/device_management_service.cc
@@ -27,18 +27,18 @@ namespace {
// Custom request context implementation that allows to override the user agent,
// amongst others. Wraps a baseline request context from which we reuse the
// networking components.
-class DeviceManagementRequestContext : public URLRequestContext {
+class DeviceManagementRequestContext : public net::URLRequestContext {
public:
- explicit DeviceManagementRequestContext(URLRequestContext* base_context);
+ explicit DeviceManagementRequestContext(net::URLRequestContext* base_context);
virtual ~DeviceManagementRequestContext();
private:
// Overriden from URLRequestContext.
virtual const std::string& GetUserAgent(const GURL& url) const;
};
DeviceManagementRequestContext::DeviceManagementRequestContext(
- URLRequestContext* base_context) {
+ net::URLRequestContext* base_context) {
// Share resolver, proxy service and ssl bits with the baseline context. This
// is important so we don't make redundant requests (e.g. when resolving proxy
// auto configuration).
@@ -76,17 +76,17 @@ class DeviceManagementRequestContextGetter : public URLRequestContextGetter {
URLRequestContextGetter* base_context_getter)
: base_context_getter_(base_context_getter) {}
- // URLRequestContextGetter overrides.
- virtual URLRequestContext* GetURLRequestContext();
+ // Overridden from URLRequestContextGetter:
+ virtual net::URLRequestContext* GetURLRequestContext();
virtual scoped_refptr<base::MessageLoopProxy> GetIOMessageLoopProxy() const;
private:
- scoped_refptr<URLRequestContext> context_;
+ scoped_refptr<net::URLRequestContext> context_;
scoped_refptr<URLRequestContextGetter> base_context_getter_;
};
-URLRequestContext*
+net::URLRequestContext*
DeviceManagementRequestContextGetter::GetURLRequestContext() {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
if (!context_) {
@@ -27,18 +27,18 @@ namespace {
virtual ~DeviceManagementRequestContext();
private:
- // Overriden from URLRequestContext.
+ // Overridden from net::URLRequestContext:
virtual const std::string& GetUserAgent(const GURL& url) const;
};

Powered by Google App Engine
This is Rietveld 408576698